${fileconfig['system']['name']}-${userinfo['nickname']}-kcwebs云管

<%include file="/app/common/html/include/static.html"/>
% if fileconfig: % if fileconfig['system']['logo']:
% endif ${fileconfig['system']['name']} % endif
% if userinfo['icon']: % endif
${userinfo['nickname']}
% if userinfo['icon'] and userinfo['name']: ${userinfo['name']} % endif 设置登录密码 % if userinfo['role']['id']==1: 重启 % endif 退出系统
{{item.title}}
{{item.title}}
运行中 应用重启中 服务器重启中 等待服务器启动
重启服务器 重启当前应用